import { InterfaceImplementationMissingError } from './errors/InterfaceImplementationMissingError.mjs';

/**
 * Defines the endianness of a number serializer.
 * @category Serializers
 */
let Endian;

/**
 * Represents all the size options for array-like serializers
 * — i.e. `array`, `map` and `set`.
 *
 * It can be one of the following:
 * - a {@link NumberSerializer} that prefixes its content with its size.
 * - a fixed number of items.
 * - or `'remainder'` to infer the number of items by dividing
 *   the rest of the buffer by the fixed size of its item.
 *   Note that this option is only available for fixed-size items.
 *
 * @category Serializers
 */
(function (Endian) {
  Endian["Little"] = "le";
  Endian["Big"] = "be";
})(Endian || (Endian = {}));
/**
 * An implementation of the {@link SerializerInterface} that throws an error when called.
 * @category Serializers
 */
function createNullSerializer() {
  const errorHandler = () => {
    throw new InterfaceImplementationMissingError('SerializerInterface', 'serializer');
  };
  return {
    tuple: errorHandler,
    array: errorHandler,
    map: errorHandler,
    set: errorHandler,
    option: errorHandler,
    nullable: errorHandler,
    struct: errorHandler,
    enum: errorHandler,
    dataEnum: errorHandler,
    string: errorHandler,
    bool: errorHandler,
    unit: errorHandler,
    u8: errorHandler,
    u16: errorHandler,
    u32: errorHandler,
    u64: errorHandler,
    u128: errorHandler,
    i8: errorHandler,
    i16: errorHandler,
    i32: errorHandler,
    i64: errorHandler,
    i128: errorHandler,
    f32: errorHandler,
    f64: errorHandler,
    bytes: errorHandler,
    publicKey: errorHandler
  };
}

export { Endian, createNullSerializer };
//# sourceMappingURL=SerializerInterface.mjs.map
