import type { Serializer } from '../Serializer';
/**
 * Concatenates an array of `Uint8Array`s into a single `Uint8Array`.
 * @category Utils
 */
export declare const mergeBytes: (bytesArr: Uint8Array[]) => Uint8Array;
/**
 * Pads a `Uint8Array` with zeroes to the specified length.
 * If the array is longer than the specified length, it is returned as-is.
 * @category Utils
 */
export declare const padBytes: (bytes: Uint8Array, length: number) => Uint8Array;
/**
 * Fixes a `Uint8Array` to the specified length.
 * If the array is longer than the specified length, it is truncated.
 * If the array is shorter than the specified length, it is padded with zeroes.
 * @category Utils
 */
export declare const fixBytes: (bytes: Uint8Array, length: number) => Uint8Array;
/**
 * A string serializer that uses UTF-8 encoding
 * using the native `TextEncoder` API.
 * @category Serializers
 */
export declare const utf8: Serializer<string>;
/**
 * A string serializer that uses a custom alphabet.
 * This can be used to create serializers for base58, base64, etc.
 * @category Serializers
 */
export declare const baseX: (alphabet: string) => Serializer<string>;
/**
 * A string serializer that uses base10 encoding.
 * @category Serializers
 */
export declare const base10: Serializer<string>;
/**
 * A string serializer that uses base58 encoding.
 * @category Serializers
 */
export declare const base58: Serializer<string>;
/**
 * A string serializer that uses base64 encoding.
 * @category Serializers
 */
export declare const base64: Serializer<string>;
/**
 * A string serializer that uses base16 encoding.
 * @category Serializers
 */
export declare const base16: Serializer<string>;
/**
 * An array of boolean serializer that
 * converts booleans to bits and vice versa.
 * @category Serializers
 */
export declare const bitArray: (size: number, backward?: boolean) => Serializer<boolean[]>;
